@@ -179,21 +179,24 @@ class Playlist(Sequence):
             ][
                 "playlistVideoListRenderer"
             ]
+            videos = important_content["contents"]
         except (KeyError, IndexError, TypeError):
             try:
                 # this is the json tree structure, if the json was directly sent
                 # by the server in a continuation response
-                important_content = initial_data[1]["response"][
-                    "continuationContents"
-                ]["playlistVideoListContinuation"]
+                important_content = initial_data[1]['response']['onResponseReceivedActions'][
+                    0
+                ]['appendContinuationItemsAction']['continuationItems']
+                videos = important_content
             except (KeyError, IndexError, TypeError) as p:
                 print(p)
                 return [], None
-        videos = important_content["contents"]
+
         try:
-            continuation = important_content["continuations"][0][
-                "nextContinuationData"
-            ]["continuation"]
+            continuation = videos[-1]['continuationItemRenderer'][
+                'continuationEndpoint'
+            ]['continuationCommand']['token']
+            videos = videos[:-1]
         except (KeyError, IndexError):
             # if there is an error, no continuation is available
             continuation = None
@@ -319,12 +322,17 @@ class Playlist(Sequence):
         :param resolution:
             Video resolution i.e. "720p", "480p", "360p", "240p", "144p"
         :type resolution: str
+        :rtype: List[str]
+        :returns:
+            List of filepaths for downloaded videos.
         """
         logger.debug("total videos found: %d", len(self.video_urls))
         logger.debug("starting download")
 
         prefix_gen = self._path_num_prefix_generator(reverse_numbering)
 
+        downloaded_filepaths = []
+
         for link in self.video_urls:
             youtube = YouTube(link)
             dl_stream = (
@@ -337,11 +345,14 @@ class Playlist(Sequence):
             if prefix_number:
                 prefix = next(prefix_gen)
                 logger.debug("file prefix is: %s", prefix)
-                dl_stream.download(download_path, filename_prefix=prefix)
+                dl_path = dl_stream.download(download_path, filename_prefix=prefix)
             else:
-                dl_stream.download(download_path)
+                dl_path = dl_stream.download(download_path)
+            downloaded_filepaths.append(dl_path)
             logger.debug("download complete")
 
+        return downloaded_filepaths
+
     @cache
     def title(self) -> Optional[str]:
         """Extract playlist title
