@@ -4,6 +4,7 @@ import json
 import logging
 import re
 from collections import OrderedDict
+from datetime import datetime
 from typing import Any
 from typing import Dict
 from typing import List
@@ -22,6 +23,62 @@ from pytube.helpers import regex_search
 logger = logging.getLogger(__name__)
 
 
+def publish_date(watch_html: str):
+    """Extract publish date
+    :param str watch_html:
+        The html contents of the watch page.
+    :rtype: str
+    :returns:
+        Publish date of the video.
+    """
+    try:
+        result = regex_search(
+            r"(?<=itemprop=\"datePublished\" content=\")\d{4}-\d{2}-\d{2}",
+            watch_html, group=0
+        )
+    except RegexMatchError:
+        return None
+    return datetime.strptime(result, '%Y-%m-%d')
+
+
+def recording_available(watch_html):
+    """Check if live stream recording is available.
+
+    :param str watch_html:
+        The html contents of the watch page.
+    :rtype: bool
+    :returns:
+        Whether or not the content is private.
+    """
+    unavailable_strings = [
+        'This live stream recording is not available.'
+    ]
+    for string in unavailable_strings:
+        if string in watch_html:
+            return False
+    return True
+
+
+def is_private(watch_html):
+    """Check if content is private.
+
+    :param str watch_html:
+        The html contents of the watch page.
+    :rtype: bool
+    :returns:
+        Whether or not the content is private.
+    """
+    private_strings = [
+        "This is a private video. Please sign in to verify that you may see it.",
+        "\"simpleText\":\"Private video\"",
+        "This video is private."
+    ]
+    for string in private_strings:
+        if string in watch_html:
+            return True
+    return False
+
+
 def is_age_restricted(watch_html: str) -> bool:
     """Check if content is age restricted.
 
@@ -71,7 +128,6 @@ def video_info_url(video_id: str, watch_url: str) -> str:
     params = OrderedDict(
         [
             ("video_id", video_id),
-            ("el", "$el"),
             ("ps", "default"),
             ("eurl", quote(watch_url)),
             ("hl", "en_US"),
@@ -118,7 +174,10 @@ def js_url(html: str) -> str:
     :param str html:
         The html contents of the watch page.
     """
-    base_js = get_ytplayer_js(html)
+    try:
+        base_js = get_ytplayer_config(html)['assets']['js']
+    except KeyError:
+        base_js = get_ytplayer_js(html)
     return "https://youtube.com" + base_js
 
 
@@ -159,7 +218,7 @@ def get_ytplayer_js(html: str) -> Any:
         Path to YouTube's base.js file.
     """
     js_url_patterns = [
-        r"\"jsUrl\":\"([^\"]*)\"",
+        r"(/s/player/[\w\d]+/[\w\d_/.]+/base\.js)"
     ]
     for pattern in js_url_patterns:
         regex = re.compile(pattern)
@@ -187,13 +246,10 @@ def get_ytplayer_config(html: str) -> Any:
     :returns:
         Substring of the html containing the encoded manifest data.
     """
+    logger.debug("finding initial function name")
     config_patterns = [
         r";ytplayer\.config\s*=\s*({.*?});",
-        r";ytplayer\.config\s*=\s*({.+?});ytplayer",
-        r";yt\.setConfig\(\{'PLAYER_CONFIG':\s*({.*})}\);",
-        r";yt\.setConfig\(\{'PLAYER_CONFIG':\s*({.*})(,'EXPERIMENT_FLAGS'|;)",  # noqa: E501
     ]
-    logger.debug("finding initial function name")
     for pattern in config_patterns:
         regex = re.compile(pattern)
         function_match = regex.search(html)
@@ -202,8 +258,24 @@ def get_ytplayer_config(html: str) -> Any:
             yt_player_config = function_match.group(1)
             return json.loads(yt_player_config)
 
+    # setConfig() needs to be handled a little differently.
+    # We want to parse the entire argument to setConfig()
+    #  and use then load that as json to find PLAYER_CONFIG
+    #  inside of it.
+    setconfig_patterns = [
+        r"yt\.setConfig\((.*'PLAYER_CONFIG':\s*{.+?})\);",
+        r"yt\.setConfig\((.*\"PLAYER_CONFIG\":\s*{.+?})\);"
+    ]
+    for pattern in setconfig_patterns:
+        regex = re.compile(pattern)
+        function_match = regex.search(html)
+        if function_match:
+            logger.debug("finished regex search, matched: %s", pattern)
+            yt_config = function_match.group(1)
+            return json.loads(yt_config)['PLAYER_CONFIG']
+
     raise RegexMatchError(
-        caller="get_ytplayer_config", pattern="config_patterns"
+        caller="get_ytplayer_config", pattern="config_patterns, setconfig_patterns"
     )
 
 
@@ -278,14 +350,12 @@ def apply_descrambler(stream_data: Dict, key: str) -> None:
     if key == "url_encoded_fmt_stream_map" and not stream_data.get(
         "url_encoded_fmt_stream_map"
     ):
-        formats = json.loads(stream_data["player_response"])["streamingData"][
-            "formats"
-        ]
-        formats.extend(
-            json.loads(stream_data["player_response"])["streamingData"][
-                "adaptiveFormats"
-            ]
-        )
+        streaming_data = json.loads(stream_data["player_response"])["streamingData"]
+        formats = []
+        if 'formats' in streaming_data.keys():
+            formats.extend(streaming_data['formats'])
+        if 'adaptiveFormats' in streaming_data.keys():
+            formats.extend(streaming_data['adaptiveFormats'])
         try:
             stream_data[key] = [
                 {
